@@ -43,6 +43,7 @@ class NodeConfig(BaseModel):
     appendix_properties: T.List[str] = []
     ignore_properties: T.List[str] = []
     basemodel_properties: T.Dict[str, PropertyConfig] = {}
+    dict_properties: list[str] = []
 
 
 class DBConfig(BaseModel):
@@ -338,13 +339,19 @@ def build_from_str_validator_str(node_config: T.Optional[NodeConfig]) -> str:
     if not node_config:
         return ""
     field_name_strs: T.List[str] = []
+
+    def key_from_field_name(f_name: str) -> str:
+        k = f_name
+        if f_name in node_config.appendix_properties:
+            k += "_"
+        return f'"{k}"'
+
+    for field_name in node_config.dict_properties:
+        field_name_strs.append(key_from_field_name(field_name))
     for field_name, props_config in node_config.basemodel_properties.items():
         if props_config.validate_as_basemodel is False:
             continue
-        key = field_name
-        if field_name in node_config.appendix_properties:
-            key += "_"
-        field_name_strs.append(f'"{key}"')
+        field_name_strs.append(key_from_field_name(field_name))
     if not field_name_strs:
         return ""
     return f"""
@@ -426,6 +433,8 @@ def build_node_and_resolver(
             type_str = prop.type_str_basemodel(
                 module_name, cardinality=prop_config.cardinality
             )
+        elif node_config and prop.name in node_config.dict_properties:
+            type_str = prop.type_str.replace("str", "dict")
         else:
             type_str = prop.type_str
         if not (prop.is_computed or is_appendix):
@@ -590,6 +599,8 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
         [] if not node_config else node_config.basemodel_properties.keys()
     )
     basemodel_properties_str = f"_basemodel_properties: T.ClassVar[T.Set[str]] = {stringify_set(set(basemodel_properties))}"
+    dict_properties = [] if not node_config else node_config.dict_properties
+    dict_properties_str = f"_dict_properties: T.ClassVar[T.Set[str]] = {stringify_set(set(dict_properties))}"
     node_link_functions_str = "\n".join(link_function_strs)
     update_function_str = build_update_function_str(
         node_resolver_name=node_resolver_name, links=object_type.links
@@ -608,6 +619,7 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
         computed_properties_str,
         appendix_properties_str,
         basemodel_properties_str,
+        dict_properties_str,
         node_link_functions_str,
         update_function_str,
         orm_config_str,
